<!-- DO NOT EDIT THIS FILE MANUALLY. This file is generated by generate_readme.py. -->

# imgviz: Image Visualization Tools

[![PyPI Version](https://img.shields.io/pypi/v/imgviz.svg)](https://pypi.python.org/pypi/imgviz)
[![Python Versions](https://img.shields.io/pypi/pyversions/imgviz.svg)](https://pypi.org/project/imgviz)
[![Build Status](https://travis-ci.com/wkentaro/imgviz.svg?token=zM5rExyvuRoJThsnqHAF&branch=master)](https://travis-ci.com/wkentaro/imgviz)

## Installation

```bash
pip install imgviz
```

## Getting Started

```python
# getting_started.py
import matplotlib.pyplot as plt

import imgviz


data = imgviz.data.arc2017()

depth_viz = imgviz.depth2rgb(data['depth'], min_value=0.3, max_value=1)

tiled = imgviz.tile([data['rgb'], depth_viz], border=(255, 255, 255))

plt.imshow(tiled)
plt.axis('off')
plt.show()

```

## [Examples](examples)

<table>
	<tr>
		<td><pre><a href="examples/centerize.py">examples/centerize.py</a></pre></td>
		<td><img src="examples/.readme/centerize.jpg" height="200px" /></td>
	</tr>
	<tr>
		<td><pre><a href="examples/color.py">examples/color.py</a></pre></td>
		<td><img src="examples/.readme/color.jpg" height="200px" /></td>
	</tr>
	<tr>
		<td><pre><a href="examples/depth2rgb.py">examples/depth2rgb.py</a></pre></td>
		<td><img src="examples/.readme/depth2rgb.jpg" height="200px" /></td>
	</tr>
	<tr>
		<td><pre><a href="examples/rectangle.py">examples/rectangle.py</a></pre></td>
		<td><img src="examples/.readme/rectangle.jpg" height="200px" /></td>
	</tr>
	<tr>
		<td><pre><a href="examples/resize.py">examples/resize.py</a></pre></td>
		<td><img src="examples/.readme/resize.jpg" height="200px" /></td>
	</tr>
	<tr>
		<td><pre><a href="examples/tile.py">examples/tile.py</a></pre></td>
		<td><img src="examples/.readme/tile.jpg" height="200px" /></td>
	</tr>
</table>
